@@ -13,6 +13,7 @@
 # ****************************************************************
 from core import celery_app
 from django.contrib.auth import get_user_model
+from django.utils.translation import gettext_lazy as _
 from oasis.models import Client
 from typing import Any
 
@@ -23,6 +24,7 @@ def task_sync_users(app: Any):
     Task to get user state, email and other variables to user table.
     :return: None
     """
+
     user_model = get_user_model()
     user_qs = user_model.objects.all()
     for user in user_qs:
@@ -30,13 +32,30 @@ def task_sync_users(app: Any):
             document_id = user.profile.document_id
             try:
                 oasis_customer = Client.objects.get_by_pk(pk=document_id).get()
-                user.is_active = True if oasis_customer == "A" else False
+                if user.is_active != (oasis_customer.state == "A"):
+                    user.is_active = (oasis_customer.state == "A")
+
                 if user.email != oasis_customer.main_email:
                     user.email = oasis_customer.main_email
-                user.save()
+
+                # Changes in profile
+                if oasis_customer.segmentid is not None:
+                    if user.profile.segment != oasis_customer.segmentid:
+                        user.profile.segment = oasis_customer.segmentid
+
+                if user.profile.type != oasis_customer.customer_type:
+                    user.profile.type = oasis_customer.customer_type
+
             except Client.DoesNotExist:
                 user.is_active = False
             except Exception as exc:
-                pass
+                raise Exception(_("Error at sync users.")) from exc
+            else:
+                try:
+                    user.profile.save()
+                except Exception as exc:
+                    raise Exception(_("Error saving user profile.")) from exc
+                else:
+                    user.save()
 
 
