@@ -20,6 +20,8 @@ routers = DefaultRouter()
 
 urlpatterns = [
     path(r"", include(routers.get_urls())),
+    path(r"change/", services.OasisAuthServices.as_view({"post": "change_password"})),
+    path(r"retrieve/", services.OasisAuthServices.as_view({"post": "retrieve"})),
     path(r"register/", services.OasisAuthServices.as_view({"post": "register"})),
     path(r"login/", services.OasisAuthServices.as_view({"post": "login"})),
     path(r"validate/", services.OasisAuthServices.as_view({"post": "validate_code"}))
